@@ -754,13 +754,9 @@ output$DP_plot_DIF_NLR <- downloadHandler(
 output$tab_coef_DIF_NLR <- renderTable({
   item <- input$difnlrSlider
   fit <- model_DIF_NLR_plot()
-  DIFitems <- fit$DIFitems
 
-  tab_coef <- tab_sd <- rep(0, 5)
-  names(tab_coef) <- names(tab_sd) <- c("a", "b", "aDif", "bDif", "c")
-
-  tab_coef[names(fit$nlrPAR[item, ])] <- fit$nlrPAR[item, ]
-  tab_sd[names(fit$nlrSE[item, ])] <- fit$nlrSE[item, ]
+  tab_coef <- fit$nlrPAR[[item]][c('a', 'b', 'aDif', 'bDif', 'c')]
+  tab_sd <- fit$nlrSE[[item]][c('a', 'b', 'aDif', 'bDif', 'c')]
 
   tab <- t(rbind(tab_coef, tab_sd))
   rownames(tab) <- c('a', 'b', 'aDIF', 'bDIF', 'c')
@@ -1149,6 +1145,7 @@ include.colnames = T)
 model_DDF_print <- reactive({
   group <- unlist(DIF_groups())
   a <- data.frame(test_answers())
+  colnames(a) <- item_names()
   k <- test_key()
 
   adj.method <- input$correction_method_print_DDF
@@ -1165,6 +1162,7 @@ model_DDF_print <- reactive({
 model_DDF_print_report <- reactive({
   group <- unlist(DIF_groups())
   a <- data.frame(test_answers())
+  colnames(a) <- item_names()
   k <- test_key()
 
   if (!input$customizeCheck) {
@@ -1193,6 +1191,7 @@ output$print_DDF <- renderPrint({
 model_DDF_plot <- reactive({
   group <- unlist(DIF_groups())
   a <- data.frame(test_answers())
+  colnames(a) <- item_names()
   k <- test_key()
 
   adj.method <- input$correction_method_plot_DDF
@@ -1221,6 +1220,7 @@ plot_DDFInput <- reactive({
 plot_DDFReportInput <- reactive({
   group <- unlist(DIF_groups())
   a <- data.frame(test_answers())
+  colnames(a) <- item_names()
   k <- test_key()
 
   if (!input$customizeCheck) {
@@ -1242,10 +1242,8 @@ plot_DDFReportInput <- reactive({
   for (i in 1:length(mod$DDFitems)) {
     g <- plot(mod, item = mod$DDFitems[i])[[1]] +
       theme(text = element_text(size = 12),
-            plot.title = element_text(size = 12, face = "bold",
-                                      vjust = 1.5)) +
-      ggtitle(paste("\nDDF multinomial plot for item",
-                    item_numbers()[mod$DDFitems[i]]))
+            plot.title = element_text(size = 12, face = "bold", vjust = 1.5)) +
+      ggtitle(paste("\nDDF multinomial plot for item ", item_numbers()[mod$DDFitems[i]]))
     graflist[[i]] <- g
   }
   #} else {
